@@ -3,16 +3,19 @@ import os
 from .base import SqlReader, NameCompare
 from .engine import Engine
 
+
 class PostgresReader(SqlReader):
     """
         A dumb pipe that gets a rowset back from a database using
         a SQL string, and converts types to some useful subset
     """
+
     ENGINE = Engine.POSTGRES
 
     def __init__(self, host, database, user, password=None, port=None):
         super().__init__(PostgresNameCompare(), PostgresSerializer())
         import psycopg2
+
         self.api = psycopg2
         self.host = host
         self.database = database
@@ -20,8 +23,8 @@ class PostgresReader(SqlReader):
         self.port = port
 
         if password is None:
-            if 'POSTGRES_PASSWORD' in os.environ:
-                password = os.environ['POSTGRES_PASSWORD']
+            if "POSTGRES_PASSWORD" in os.environ:
+                password = os.environ["POSTGRES_PASSWORD"]
         self.password = password
 
         self.update_connection_string()
@@ -45,18 +48,24 @@ class PostgresReader(SqlReader):
             Will fix to target approprate dialect. Needs symbols.
         """
         self.connection_string = "user='{0}' host='{1}'".format(self.user, self.host)
-        self.connection_string += " dbname='{0}'".format(self.database) if self.database is not None else ""
+        self.connection_string += (
+            " dbname='{0}'".format(self.database) if self.database is not None else ""
+        )
         self.connection_string += " port={0}".format(self.port) if self.port is not None else ""
-        self.connection_string += " password='{0}'".format(self.password) if self.password is not None else ""
+        self.connection_string += (
+            " password='{0}'".format(self.password) if self.password is not None else ""
+        )
 
     def switch_database(self, dbname):
         sql = "\\c " + dbname
         self.execute(sql)
 
+
 class PostgresSerializer:
     def serialize(self, query):
         return str(query)
 
+
 class PostgresNameCompare(NameCompare):
     def __init__(self, search_path=None):
         self.search_path = search_path if search_path is not None else ["public"]
@@ -67,9 +76,9 @@ class PostgresNameCompare(NameCompare):
         if query == meta:
             return True
         if self.is_escaped(meta) and meta.lower() == meta:
-            meta = meta.lower().replace('"','')
+            meta = meta.lower().replace('"', "")
         if self.is_escaped(query) and query.lower() == query:
-            query = query.lower().replace('"','')
+            query = query.lower().replace('"', "")
         return meta == query
 
     def should_escape(self, identifier):
@@ -77,7 +86,7 @@ class PostgresNameCompare(NameCompare):
             return False
         if identifier.lower() in self.reserved():
             return True
-        if identifier.replace(' ', '') == identifier.lower():
+        if identifier.replace(" ", "") == identifier.lower():
             return False
         else:
             return True
